<?php

namespace App\Console\Commands;

use Carbon\Carbon;
use App\Models\Subscription;
use Illuminate\Console\Command;
use App\Models\SubscriptionTransaction;
use App\Models\SubscriptionTransactionDetail;

class GenerateSubscriptionTransactions extends Command
{
    protected $signature = 'generate:subscription-transactions';
    protected $description = 'Generate subscription transactions based on delivery frequency';

    public function handle()
    {
        try {
            // Get all subscriptions with a valid delivery frequency
            $subscriptions = Subscription::whereIn('delivery_frequency', [7, 14, 30])->get();

            foreach ($subscriptions as $subscription) {
                $lastTransaction = SubscriptionTransaction::where('subscription_id', $subscription->id)
                    ->latest('created_at')
                    ->first();

                if ($lastTransaction) {
                    // Calculate the next transaction date based on delivery frequency
                    $nextTransactionDate = Carbon::parse($lastTransaction->created_at)
                        ->addDays($subscription->delivery_frequency);

                    // Use Carbon::now() to compare against the next transaction date
                    $now = Carbon::now();

                    if ($nextTransactionDate->isToday() || $nextTransactionDate->isPast()) {
                        // Create a new transaction
                        $newTransaction = SubscriptionTransaction::create([
                            'subscription_id' => $subscription->id,
                            'total' => $lastTransaction->total,
                            'payment_status' => 'Pending', // Default status
                            'note' => 'Auto-generated transaction based on previous',
                        ]);

                        // Copy details from the last transaction
                        $lastTransactionDetails = SubscriptionTransactionDetail::where('subscription_transaction_id', $lastTransaction->id)->get();

                        foreach ($lastTransactionDetails as $detail) {
                            SubscriptionTransactionDetail::create([
                                'subscription_transaction_id' => $newTransaction->id,
                                'product_id' => $detail->product_id,
                                'quantity' => $detail->quantity,
                                'subtotal' => $detail->subtotal,
                            ]);
                        }

                        $this->info("New transaction created for subscription ID: {$subscription->id}");
                    } else {
                        $this->info("Next transaction not due yet for subscription ID: {$subscription->id}. Next due date: {$nextTransactionDate->toDateString()}");
                    }
                } else {
                    $this->warn("No previous transactions found for subscription ID: {$subscription->id}");
                }
            }
        } catch (\Exception $e) {
            $this->error("Error: " . $e->getMessage());
            $this->error("File: " . $e->getFile());
            $this->error("Line: " . $e->getLine());
        }
    }
}
