<?php

namespace App\Http\Controllers;

use App\Models\AboutUsImage;
use Illuminate\Http\Request;
use Yajra\DataTables\DataTables;

class AboutUsImageController extends Controller
{
    public function index()
    {
        if (request()->ajax()) {
            $about_us_image = AboutUsImage::query();

            return DataTables::of($about_us_image)
                ->addColumn('image', function ($about_us_images) {
                    return '<img src="' . asset($about_us_images->image) . '" alt="Image" class="w-32">';
                })
                ->addColumn('action', function ($about_us_images) {
                    return '<a href="' . route('about_us_image.edit', $about_us_images->id) . '" class="text-black"><i class="text-4xl bx bx-edit"></i></a>
                            <form action="' . route('about_us_image.destroy', $about_us_images->id) . '" method="POST" style="display: inline-block;">
                                ' . csrf_field() . '
                                ' . method_field('DELETE') . '
                                <button type="submit" class="text-red-500"><i class="text-4xl bx bx-trash"></i></button>
                            </form>
                           ';
                })
                ->rawColumns(['image', 'action'])
                ->make(true);
        }

        return view('admin.about_us_image.index'); // Ensure this view exists
    }

    public function create()
    {
        $about_us_image = AboutUsImage::all();
        return view('admin.about_us_image.create', compact('about_us_image'));
    }

    public function store(Request $request)
    {
        // Validate the request
        $request->validate([
            'image' => 'required|max:2048',
        ]);


        if ($request->hasFile('image')) {
            $image = $request->file('image');
            $imageName = time() . '_' . $image->getClientOriginalName();
            $image->move(public_path('images/uploads'), $imageName);
            // Set the image path if the upload is successful
            $image = 'images/uploads/' . $imageName;
        }

        // Create the banner
        AboutUsImage::create([
            'image' => $image, // Pass the image path or null
        ]);

        return redirect()->route('about_us_image.index')->with('success', 'Image created successfully!');
    }

    public function edit($id)
    {
        $about_us_image = AboutUsImage::findOrFail($id);
        return view('admin.about_us_image.edit', compact('about_us_image'));
    }

    public function update(Request $request, $id)
    {
        $request->validate([
            'image' => 'nullable|max:2048',
        ]);

        // Find the banner by ID
        $about_us_image = AboutUsImage::findOrFail($id);

        // Handle the image upload
        if ($request->hasFile('image')) {
            $image = $request->file('image');
            $imageName = time() . '_' . $image->getClientOriginalName();
            $image->move(public_path('images/uploads'), $imageName);
            // Set the image path if the upload is successful
            $image = 'images/uploads/' . $imageName;
            $about_us_image->image = $image;
        }

        // Save the updated about_us_images
        $about_us_image->save();

        // Redirect with success message
        return redirect()->route('about_us_image.index')->with('success', 'Image updated successfully.');
    }

    public function destroy($id)
    {
        $about_us_image = AboutUsImage::findOrFail($id);
        $about_us_image->delete();

        return redirect()->route('about_us_image.index')->with('success', 'Image deleted successfully');
    }
}
