<?php

namespace App\Http\Controllers;

use App\Models\Banner;
use Illuminate\Http\Request;
use Yajra\DataTables\DataTables;

class BannerController extends Controller
{
    public function index()
    {
        if (request()->ajax()) {
            $banners = Banner::query();

            return DataTables::of($banners)
                ->addColumn('title', function ($banner) {
                    return $banner->title;
                })
                ->addColumn('subtitle', function ($banner) {
                    return $banner->subtitle;
                })
                ->addColumn('image', function ($banner) {
                    return '<img src="' . asset($banner->image) . '" alt="Image" class="w-32">';
                })
                ->addColumn('action', function ($banner) {
                    return '<a href="' . route('banners.edit', $banner->id) . '" class="text-black"><i class="text-4xl bx bx-edit"></i></a>
                            <form action="' . route('banners.destroy', $banner->id) . '" method="POST" style="display: inline-block;">
                                ' . csrf_field() . '
                                ' . method_field('DELETE') . '
                                <button type="submit" class="text-red-500"><i class="text-4xl bx bx-trash"></i></button>
                            </form>
                           ';
                })
                ->rawColumns(['title', 'subtitle', 'image', 'action'])
                ->make(true);
        }

        return view('admin.banners.index'); // Ensure this view exists
    }

    public function create()
    {
        $categories = Banner::all();
        return view('admin.banners.create', compact('categories'));
    }

    public function store(Request $request)
    {
        // Validate the request
        $request->validate([
            'title' => 'nullable|string|max:255',
            'subtitle' => 'nullable|string|max:255',
            'banner_type' => 'required|string|max:255',
            'image' => 'required|image|mimes:jpg,jpeg,png,gif,webp|max:2048',
        ]);


        if ($request->hasFile('image')) {
            $image = $request->file('image');
            $imageName = time() . '_' . $image->getClientOriginalName();
            $image->move(public_path('images/uploads'), $imageName);
            // Set the image path if the upload is successful
            $image = 'images/uploads/' . $imageName;
        }

        // Create the banner
        Banner::create([
            'title' => $request->input('title'),
            'subtitle' => $request->input('subtitle'),
            'banner_type' => $request->input('banner_type'),
            'image' => $image, // Pass the image path or null
        ]);

        return redirect()->route('banners.index')->with('success', 'Banner created successfully!');
    }

    public function edit($id)
    {
        $banner = Banner::findOrFail($id);
        return view('admin.banners.edit', compact('banner'));
    }

    public function update(Request $request, $id)
    {
        // Validate the request
        $request->validate([
            'title' => 'nullable|string|max:255',
            'subtitle' => 'nullable|string|max:255',
            'banner_type' => 'required|string|max:255',
            'image' => 'nullable|image|mimes:jpg,jpeg,png,gif,webp|max:2048',
        ]);

        // Find the banner by ID
        $banner = Banner::findOrFail($id);
        $banner->title = $request->input('title');
        $banner->subtitle = $request->input('subtitle');
        $banner->banner_type = $request->input('banner_type');

        // Handle the image upload
        if ($request->hasFile('image')) {
            $image = $request->file('image');
            $imageName = time() . '_' . $image->getClientOriginalName();
            $image->move(public_path('images/uploads'), $imageName);
            // Set the image path if the upload is successful
            $image = 'images/uploads/' . $imageName;
            $banner->image = $image;
        }

        // Save the updated banner
        $banner->save();

        // Redirect with success message
        return redirect()->route('banners.index')->with('success', 'Banner updated successfully.');
    }

    public function destroy($id)
    {
        $banner = Banner::findOrFail($id);
        $banner->delete();

        return redirect()->route('banners.index')->with('success', 'Banner deleted successfully');
    }
}
