<?php

namespace App\Http\Controllers;

use App\Models\Order;
use App\Models\Product;
use App\Models\Voucher;
use App\Models\OrderDetail;
use Illuminate\Http\Request;
use App\Models\BillingInformation;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Http;
use Illuminate\Support\Facades\Session;

class BillingController extends Controller
{
    public function processBillingAndPayment2($id)
    {

        $order = Order::findOrFail($id); // Fetch the order or throw an exception if not found
        $order_id = $order->id; // Retrieve the order ID
        Session::put('order_id', $order_id); // Store the order ID in session

        // Step 6: Prepare PayMongo API Request
        $response = Http::withHeaders([
            'Content-Type' => 'application/json',
            'accept' => 'application/json',
            'authorization' => 'Basic c2tfdGVzdF9YNHZ1elRQZ0Z6Q05SWWUxb3NaWnlnaGU6',
        ])->post('https://api.paymongo.com/v1/checkout_sessions', [
            'data' => [
                'attributes' => [
                    'line_items' => $this->buildLineItems2($order),
                    'send_email_receipt' => true,
                    'show_description' => false,
                    'show_line_items' => true,
                    'cancel_url' => url('user_dashboard'),
                    'success_url' => route('payment.verify2'),
                    'statement_descriptor' => 'Your Business Name',
                    'reference_number' => (string) $order->id,
                    'payment_method_types' => ['gcash', 'card'], // Use the selected payment method
                ],
            ],
        ]);

        $responseData = $response->json();

        if ($response->successful()) {
            // Update the subscription with the selected payment method
            $order->update([
                'transaction_id' => $responseData['data']['id'] ?? null,
                'payment_method' => "NULL",  // Store the selected payment method
            ]);

            $checkoutUrl = $responseData['data']['attributes']['checkout_url'] ?? null;

            if ($checkoutUrl) {
                return redirect()->away($checkoutUrl);
            } else {
                return redirect()->back()->withErrors(['error' => 'Checkout URL not provided by PayMongo.']);
            }
        } else {
            return redirect()->back()->withErrors(['error' => $responseData['errors'][0]['detail'] ?? 'Payment processing failed.']);
        }
    }
    private function buildLineItems2($order)
    {
        $order_details = $order->orderDetails()->with('product')->get(); // Use the relation to retrieve order details

        $lineItems = [];
        $totalFinalAmount = 0;

        // Loop through the order details
        foreach ($order_details as $detail) {
            $productName = $detail->product->name ?? 'Unknown Product';
            $quantity = max((int) $detail->quantity, 1); // Ensure quantity is a positive integer
            $productPrice = $detail->product->price ?? 0; // Default price to 0 if unavailable

            // Add the line item
            $lineItems[] = [
                'name' => $productName,
                'quantity' => $quantity,
                'amount' => (int) ($productPrice * 100), // Convert to cents and ensure it's an integer
                'currency' => 'PHP',
            ];

            // Accumulate the final amount
            $totalFinalAmount += $productPrice * $quantity;
        }

        return $lineItems;
    }


    public function verify2(Request $request)
    {
        $id = Session::get('order_id');

        $order = Order::findOrFail($id);


        $url = "https://api.paymongo.com/v1/checkout_sessions/{$order->transaction_id}";
        $response = Http::withHeaders([
            'Accept' => 'application/json',
            'Authorization' => 'Basic c2tfdGVzdF9YNHZ1elRQZ0Z6Q05SWWUxb3NaWnlnaGU6',
        ])->get($url);

        $responseData = $response->json();

        if ($response->successful() && isset($responseData['data']['attributes']['payments'])) {
            $payments = $responseData['data']['attributes']['payments'];

            $status = $payments[0]['attributes']['status'];

            if ($status === 'paid') {
                $order->update(['status' => 'Paid']);
                Session::forget('cart');

                $rewardPoints = floor($order->total / 100);
                $user = $order->billingInformation->user;
                $order->redeemed_points; // Get the redeemed points from the order

                $user->reward_points = ($user->reward_points ?? 0) + $rewardPoints;
                $user->save();


                return redirect()->route('user_dashboard')->with('success', 'Subscription Paid Successfully');
            } else {
                return redirect('place_order')->withErrors(['error' => 'Payment was not successful.']);
            }
        }
    }


    public function processBillingAndPayment(Request $request)
    {
        $validatedData = $request->validate([
            'first_name' => 'required|string',
            'last_name' => 'required|string',
            'middle_name' => 'required|string',
            'email' => 'required|email',
            'phone_number' => 'required|string',
            'street_address' => 'required|string',
            'payment_method_types' => 'nullable|in:gcash,card',
            'city' => 'required|string',
            'state' => 'required|string',
            'country' => 'required|string',
            'zip_code' => 'required|string',
            'billing_id' => 'nullable',
            'total' => 'nullable|numeric|min:0',
            'product_id' => 'nullable|array',
            'quantity' => 'nullable|array',
            'subtotal' => 'nullable|array',
            'product_id.*' => 'nullable',
            'quantity.*' => 'nullable',
            'notes' => 'nullable|string',
            'redeemed_points' => 'nullable|integer|min:0', // New validation for redeem points
            'voucher_code' => 'nullable|string',
            'discount' => 'nullable',
        ]);


        $user = auth()->user();

        // Step 1: Calculate Total with Redeemed Points
        $total = $validatedData['total'];
        $redeemPoints = $validatedData['redeemed_points'] ?? 0;
        $pointValue = 1; // Define how much 1 point is worth in PHP
        $redeemAmount = $redeemPoints * $pointValue;

        if ($redeemAmount > $total) {
            $redeemAmount = $total; // Prevent redeeming more than the total
            $redeemPoints = floor($total / $pointValue);
        }

        $total -= $redeemAmount;

        if ($redeemPoints > 0) {
            // Deduct points from the user's reward points
            if ($user->redeem_balance < $redeemPoints) {
                return redirect()->back()->withErrors(['error' => 'Insufficient redeem points.']);
            }
            $user->redeem_balance -= $redeemPoints;
            $user->save();
        }



        if ($request->filled('voucher_code')) {
            $voucher = Voucher::where('code', $request->voucher_code)
                ->where('status', 'active')
                ->first();

            if (!$voucher || ($voucher->usage_limit && $voucher->used_count >= $voucher->usage_limit)) {
                return redirect()->back()->withErrors(['voucher_code' => 'Invalid or expired voucher code.']);
            }

            $usedCount = $voucher->used_count ?? 0;

            if ($voucher->usage_limit && $usedCount >= $voucher->usage_limit) {
                return redirect()->back()->withErrors(['voucher_code' => 'Voucher usage limit exceeded.']);
            }

            // Update used count
            $voucher->used_count = $usedCount + 1;
            $voucher->save();
        }

        // Step 3: Retrieve or Store Billing Information
        $billingInfo = null;

        if ($validatedData['billing_id']) {
            $billingInfo = BillingInformation::find($validatedData['billing_id']);
        }

        if (!$billingInfo) {
            $billingInfo = new BillingInformation();
            $billingInfo->user_id = $user->id;
            $billingInfo->first_name = $validatedData['first_name'];
            $billingInfo->last_name = $validatedData['last_name'];
            $billingInfo->middle_name = $validatedData['middle_name'];
            $billingInfo->email = $validatedData['email'];
            $billingInfo->phone_number = $validatedData['phone_number'];
            $billingInfo->street_address = $validatedData['street_address'];
            $billingInfo->city = $validatedData['city'];
            $billingInfo->state = $validatedData['state'];
            $billingInfo->country = $validatedData['country'];
            $billingInfo->zip_code = $validatedData['zip_code'];
            $billingInfo->is_default = 1; // Default to true
            $billingInfo->save();
        }

        // Step 4: Check for Shipping Address and Always Use Shipping Info for Order Billing ID
        $shippingInfo = null;
        if ($request->has('checkbox-table-search-1')) {
            $shippingInfo = new BillingInformation();
            $shippingInfo->user_id = $user->id;
            $shippingInfo->first_name = $request->input('shipping_first_name');
            $shippingInfo->last_name = $request->input('shipping_last_name');
            $shippingInfo->middle_name = $request->input('shipping_middle_name');
            $shippingInfo->email = $request->input('shipping_email');
            $shippingInfo->phone_number = $request->input('shipping_phone_number');
            $shippingInfo->street_address = $request->input('shipping_street_address');
            $shippingInfo->city = $request->input('shipping_city');
            $shippingInfo->state = $request->input('shipping_state');
            $shippingInfo->country = $request->input('shipping_country');
            $shippingInfo->zip_code = $request->input('shipping_zip_code');
            $shippingInfo->is_default = 0; // Set is_default to false for shipping address
            $shippingInfo->save();
        }

        // Use shippingInfo ID as the billing ID in the order if it exists
        $billingIdForOrder = $shippingInfo ? $shippingInfo->id : $billingInfo->id;

        $uploadedImages = session('uploaded_images', []);
        // Step 5: Create Order Record
        $order = new Order();
        $order->billing_id = $billingIdForOrder;
        $order->total = $validatedData['total']; // Update total after applying redeemed points
        $order->redeemed_points = $redeemPoints; // Save redeemed points in the order
        $order->discount = $validatedData['discount'];
        $order->notes = $validatedData['notes'] ?? '';
        $order->payment_method = $validatedData['payment_method_types'];
        $order->status = 'unpaid';

        if (isset($uploadedImages['upload_prescription'])) {
            $order->upload_prescription = $uploadedImages['upload_prescription'];
        }
        if (isset($uploadedImages['discount_proof'])) {
            $order->discount_proof = $uploadedImages['discount_proof'];
        }

        $order->save();

        Session::put('order_id', $order->id);

        // Step 6: Create Order Details for each product
        foreach ($request->product_id as $key => $productId) {
            OrderDetail::create([
                'order_id' => $order->id,
                'product_id' => $productId,
                'quantity' => $request->quantity[$key],
                'subtotal' => $request->subtotal[$key],
            ]);
        }

        // Step 6: Prepare PayMongo API Request
        $response = Http::withHeaders([
            'Content-Type' => 'application/json',
            'accept' => 'application/json',
            'authorization' => 'Basic c2tfdGVzdF9YNHZ1elRQZ0Z6Q05SWWUxb3NaWnlnaGU6',
        ])->post('https://api.paymongo.com/v1/checkout_sessions', [
            'data' => [
                'attributes' => [
                    'line_items' => $this->buildLineItems($request),
                    'payment_method_types' => [$validatedData['payment_method_types']],
                    'send_email_receipt' => true,
                    'show_description' => false,
                    'show_line_items' => true,
                    'cancel_url' => route('place_order'),
                    'success_url' => route('payment.verify'),
                    'statement_descriptor' => 'Your Business Name',
                    'reference_number' => (string) $order->id,
                ],
            ],
        ]);

        $responseData = $response->json();

        if ($response->successful()) {
            $order->update([
                'transaction_id' => $responseData['data']['id'],
            ]);

            $checkoutUrl = $responseData['data']['attributes']['checkout_url'];
            return redirect()->away($checkoutUrl);
        } else {
            return redirect()->back()->withErrors(['error' => $responseData['errors'][0]['detail'] ?? 'Payment processing failed.']);
        }
    }

    private function buildLineItems(Request $request)
    {
        $lineItems = [];
        $redeemedPoints = (int) $request->input('redeemed_points', 0); // Get redeemed points from the form
        $totalAmount = (float) $request->total; // Get the total amount for the order
        $discount = (float) $request->input('discount', 0); // Get discount from the form (or passed from controller)
        $lineItemDescription = ''; // Initialize description for all products
        $totalProductAmount = 0; // Initialize total amount for all products

        // Check if the product_id is an array and is not empty
        if (is_array($request->product_id) && count($request->product_id) > 0) {
            // Loop through each product to create line items
            foreach ($request->product_id as $key => $productId) {
                $product = Product::find($productId); // Retrieve product details

                // Check if the product exists
                if ($product) {
                    $quantity = (int) $request->quantity[$key]; // Quantity of the product
                    $price = (float) $product->price; // Product price

                    // Calculate the total amount for the product (price * quantity)
                    $productTotal = $price * $quantity;

                    // Concatenate product details into a single string for the description
                    $lineItemDescription .= $product->name . " : " . number_format($price, 2) . " x " . $quantity .
                        " | Total: " . number_format($productTotal, 2) . " ; ";

                    // Add the product amount to the total
                    $totalProductAmount += $productTotal;
                }
            }
        }

        // Step 1: Apply redeemed points to the total amount
        $finalAmount = $totalProductAmount - $redeemedPoints;
        $finalAmount = max($finalAmount, 0); // Final amount can't be less than zero

        // Step 2: Apply the discount
        $finalAmount -= $discount;
        $finalAmount = max($finalAmount, 0); // Ensure the final amount doesn't go negative

        // Step 3: Include redeemed points and discount in the description
        $lineItemDescription .= " | Redeemed Points Deducted: " . number_format($redeemedPoints, 2);
        if ($discount > 0) {
            $lineItemDescription .= " | Discount Applied: " . number_format($discount, 2);
        }

        // Create a single line item with the combined description and the total amount
        $lineItems[] = [
            'name' => rtrim($lineItemDescription, ' ; '), // Remove trailing semicolon
            'quantity' => 1, // Single line item for all products
            'amount' => intval($finalAmount) * 100, // Convert to cents for payment gateway
            'currency' => 'PHP',
        ];

        return $lineItems;
    }


    public function verify(Request $request)
    {
        $id = Session::get('order_id');
        $order = Order::with('billingInformation', 'orderDetails')->findOrFail($id);

        $url = "https://api.paymongo.com/v1/checkout_sessions/{$order->transaction_id}";
        $headers = [
            'Accept' => 'application/json',
            'Authorization' => 'Basic c2tfdGVzdF9YNHZ1elRQZ0Z6Q05SWWUxb3NaWnlnaGU6',
        ];
        $response = Http::withHeaders($headers)->get($url);

        $status = $response['data']['attributes']['payments'][0]['attributes']['status'];

        if ($status === 'paid') {
            $order->update(['status' => 'Paid']);
            Session::forget('cart');

            $order->billingInformation;
            $order->orderDetails;

            $rewardPoints = floor($order->total / 100);
            $user = $order->billingInformation->user;
            $order->redeemed_points; // Get the redeemed points from the order

            $user->reward_points = ($user->reward_points ?? 0) + $rewardPoints;
            $user->save();


            return redirect()->route('order.success', ['id' => $order->id]);
        } else {
            return redirect('place_order')->withErrors(['error' => 'Payment was not successful.']);
        }
    }

    public function redeemPoints()
    {
        $user = Auth::user();
        $pointsToRedeem = $user->reward_points;

        if ($pointsToRedeem > 0) {
            // Convert reward points to redeem balance
            $user->reward_points = 0;
            $user->redeem_balance += $pointsToRedeem;
            $user->save();

            return redirect()->back()->with('success', "{$pointsToRedeem} points redeemed successfully!");
        }

        return redirect()->back()->with('error', 'No points available to redeem.');
    }
}
