<?php

namespace App\Http\Controllers;

use App\Models\Brand;
use Illuminate\Http\Request;
use Yajra\DataTables\DataTables;

class BrandController extends Controller
{
    public function index()
    {
        if (request()->ajax()) {
            $brands = Brand::query();

            return DataTables::of($brands)
                ->addColumn('image', function ($brands) {
                    return '<img src="' . asset($brands->image) . '" alt="" class="w-32">';
                })
                ->addColumn('action', function ($brand) {
                    return '<a href="' . route('brands.edit', $brand->id) . '" class="text-black"><i class="text-4xl bx bx-edit"></i></a>
                            <form action="' . route('brands.destroy', $brand->id) . '" method="POST" style="display: inline-block;">
                                ' . csrf_field() . '
                                ' . method_field('DELETE') . '
                                <button type="submit" class="text-red-500"><i class="text-4xl bx bx-trash"></i></button>
                            </form>
                           ';
                })
                ->rawColumns(['image', 'action'])
                ->make(true);
        }

        return view('admin.brands.index'); // Ensure this view exists
    }

    public function create()
    {
        return view('admin.brands.create');
    }

    public function store(Request $request)
    {
        // Validate the request
        $request->validate([
            'brand_name' => 'nullable|string|max:255',
            'image' => 'required|image|mimes:jpg,jpeg,png,gif,webp|max:2048',
        ]);


        if ($request->hasFile('image')) {
            $image = $request->file('image');
            $imageName = time() . '_' . $image->getClientOriginalName();
            $image->move(public_path('images/uploads'), $imageName);
            // Set the image path if the upload is successful
            $image = 'images/uploads/' . $imageName;
        }

        // Create the banner
        Brand::create([
            'brand_name' => $request->input('brand_name'),
            'image' => $image, // Pass the image path or null
        ]);

        return redirect()->route('brands.index')->with('success', 'Banner created successfully!');
    }

    public function edit($id)
    {
        $brands = Brand::findOrFail($id);
        return view('admin.brands.edit', compact('brands'));
    }

    public function update(Request $request, $id)
    {
        // Validate the request
        $request->validate([
            'brand_name' => 'nullable|string|max:255',
            'image' => 'nullable|image|mimes:jpg,jpeg,png,gif,webp|max:2048',
        ]);

        // Find the banner by ID
        $brand = Brand::findOrFail($id);
        $brand->brand_name = $request->input('brand_name');

        // Handle the image upload
        if ($request->hasFile('image')) {
            $image = $request->file('image');
            $imageName = time() . '_' . $image->getClientOriginalName();
            $image->move(public_path('images/uploads'), $imageName);
            // Set the image path if the upload is successful
            $image = 'images/uploads/' . $imageName;
            $brand->image = $image;
        }

        // Save the updated banner
        $brand->save();

        // Redirect with success message
        return redirect()->route('brands.index')->with('success', 'Banner updated successfully.');
    }

    public function destroy($id)
    {
        $brand = Brand::findOrFail($id);
        $brand->delete();

        return redirect()->route('brands.index')->with('success', 'Brand deleted successfully');
    }
}
