<?php

namespace App\Http\Controllers;

use App\Models\Product;
use App\Models\Voucher;
use Illuminate\Http\Request;

class CartController extends Controller
{
    public function store(Request $request)
    {
        $productId = $request->input('product_id');
        $quantity = $request->input('quantity');

        // Retrieve current cart from session or initialize a new one
        $cart = session()->get('cart', []);

        // If the product already exists, update the quantity; otherwise, add it
        if (isset($cart[$productId])) {
            $cart[$productId] += $quantity;
        } else {
            $cart[$productId] = $quantity;
        }

        // Save the updated cart to the session
        session()->put('cart', $cart);

        return response()->json(['success' => true]);
    }
    public function remove($productId)
    {
        // Retrieve the cart from the session
        $cart = session()->get('cart', []);

        // Remove the product from the cart
        if (isset($cart[$productId])) {
            unset($cart[$productId]);
            session()->put('cart', $cart);
        }

        return back()->with('message', 'Product removed from cart successfully!');
    }

    public function saveCheckout(Request $request)
    {
        // Initialize an empty array to hold cart data and a variable for the total
        $cartData = [];
        $total = 0;

        foreach ($request->products as $productId => $data) {
            if (!empty($data['selected'])) {
                $quantity = $data['quantity'];
                $product = Product::find($productId);

                // If the product is found, calculate subtotal and add product name
                if ($product) {
                    $subtotal = $product->price * $quantity;
                    $cartData[] = [
                        'product_id' => $productId,
                        'product_name' => $product->name, // Add product name to cart data
                        'product_price' => $product->price,
                        'quantity' => $quantity,
                        'subtotal' => $subtotal,
                    ];
                    $total += $subtotal;
                }
            }
        }

        // Calculate redeemed points value
        $redeemPoints = $request->input('redeemed_points', 0); // Get redeemed points from input
        $pointsValue = $redeemPoints * 1; // Assuming 1 point = ₱1
        $finalTotal = max(0, $total - $pointsValue); // Ensure total is not negative

        // Apply voucher if available
        $voucherCode = $request->input('voucher_code', null);
        $voucherDiscount = 0;

        if ($voucherCode) {
            // Validate the voucher from the database
            $voucher = Voucher::where('code', $voucherCode)->first();

            if ($voucher) {
                // Calculate the discount based on the voucher type
                if ($voucher->discount_type === 'percentage') {
                    $voucherDiscount = ($total * $voucher->discount_value / 100);
                } elseif ($voucher->discount_type === 'fixed_amount') {
                    $voucherDiscount = min($total, $voucher->discount_value);
                }

                // Update the final total with the voucher discount
                $finalTotal = max(0, $finalTotal - $voucherDiscount); // Ensure total is not negative
            } else {
                // If the voucher is not valid, add a message (optional)
                session()->flash('voucher_error', 'Invalid voucher code.');
            }
        }

        $uploadedImages = [];

        // Handle upload_prescription file
        if ($request->hasFile('upload_prescription')) {
            $file = $request->file('upload_prescription');
            $fileName = time() . '_prescription_' . $file->getClientOriginalName();
            $destinationPath = public_path('uploads/prescriptions'); // Define public path
            $file->move($destinationPath, $fileName); // Move file to the public/uploads/prescriptions
            $uploadedImages['upload_prescription'] = 'uploads/prescriptions/' . $fileName; // Save relative path
        }

        // Handle discount_proof file
        if ($request->hasFile('discount_proof')) {
            $file = $request->file('discount_proof');
            $fileName = time() . '_proof_' . $file->getClientOriginalName();
            $destinationPath = public_path('uploads/proofs'); // Define public path
            $file->move($destinationPath, $fileName); // Move file to the public/uploads/proofs
            $uploadedImages['discount_proof'] = 'uploads/proofs/' . $fileName; // Save relative path
        }

        // Save uploaded images separately in session
        session(['uploaded_images' => $uploadedImages]);

        // Save other cart data in session
        session([
            'cart_data' => $cartData,
            'instructions' => $request->instructions,
            'redeem_points' => $redeemPoints,
            'points_value' => $pointsValue,
            'voucher_code' => $voucherCode,
            'voucher_discount' => $voucherDiscount,
            'total' => $finalTotal,
        ]);


        // Return to the checkout page with session data
        return redirect()->route('place_order');
    }
}
