<?php

namespace App\Http\Controllers;

use App\Models\Order;
use Illuminate\Http\Request;
use Yajra\DataTables\DataTables;

class OrderController extends Controller
{
    public function index()
    {
        if (request()->ajax()) {
            $order = Order::with('billingInformation', 'orderDetails')->get();

            return DataTables::of($order)
                ->addColumn('courier', function ($order) {
                    return $order->shipping ? ($order->shipping->courier ?: 'No Courier yet') : 'No Courier yet';
                })
                ->addColumn('shipping_fee', function ($order) {
                    return $order->shipping ? ($order->shipping->shipping_fee ?: 'No Shipping Fee yet') : 'No Shipping Fee yet';
                })
                ->addColumn('customer_name', function ($order) {
                    return $order->billingInformation->user->name;
                })
                ->addColumn('product_name', function ($order) {
                    // Collect all products with their quantities
                    $productDetails = $order->orderDetails->map(function ($detail) {
                        return $detail->product->name . ' x ' . $detail->quantity; // Combine name and quantity
                    })->implode(', '); // Combine details with commas

                    return $productDetails ?: 'No Products'; // Return 'No Products' if none exist
                })
                ->addColumn('upload_prescription', function ($order) {
                    return '<img src="' . asset($order->upload_prescription) . '" alt="" class="w-32 ">';
                })
                ->addColumn('discount_proof', function ($order) {
                    return '<img src="' . asset($order->discount_proof) . '" alt="" class="w-32 ">';
                })

                ->addColumn('action', function ($orders) {
                    $showShippingLink = !$orders->shipping || !$orders->shipping->courier || !$orders->shipping->shipping_fee;

                    return ($showShippingLink
                        ? '<a href="' . url('admin/shipping', $orders->id) . '"><i class="text-xl text-black bx bxs-plus-circle text-nowrap">Shipping Fee</i> </a>'
                        : '');
                })

                ->addColumn('action2', function ($orders) {
                    return '
                    
                    <div class="flex flex-row gap-4">
                        <a href="' . route('orders.show', $orders->id) . '" class="text-black"><i class="text-4xl bx bx-show" ></i></a>
                        <form action="' . route('orders.destroy', $orders->id) . '" method="POST" style="display: inline-block;">
                            ' . csrf_field() . '
                            ' . method_field('DELETE') . '
                            <button type="submit" class="text-red-500"><i class="text-4xl bx bx-trash"></i></button>
                        </form>
                    </div>
                
                   ';
                })
                ->rawColumns(['upload_prescription', 'discount_proof', 'product_name', 'action', 'action2'])
                ->make(true);
        }

        return view('admin.orders.index'); // Ensure this view exists
    }

    public function show($id)
    {
        $orders = Order::with('billingInformation', 'orderDetails', 'shipping')->findOrFail($id);
        return view('admin.orders.show', compact('orders'));
    }

    public function destroy($id)
    {
        $order = Order::findOrFail($id);

        // Delete each order detail
        foreach ($order->orderDetails as $orderDetail) {
            $orderDetail->delete();
        }

        // Delete the order
        $order->delete();

        return redirect()->back()->with('success', 'Order deleted successfully.');
    }
}
