<?php

namespace App\Http\Controllers;

use App\Models\AboutUsImage;
use App\Models\Blogs;
use App\Models\Order;
use App\Models\Product;
use App\Models\Voucher;
use App\Models\Category;
use App\Models\Wishlist;
use Illuminate\Http\Request;
use App\Models\BillingInformation;
use App\Models\Brand;
use App\Models\Subscription;
use App\Models\Banner;


class PageController extends Controller
{
    public function home()
    {
        $banners = Banner::all();
        $blogs = Blogs::all();
        $category = Category::all();
        $products = Product::all();
        $featured_products = Product::where('featured', 'Featured')->orderBy('created_at', 'desc')->get();

        return view('welcome', compact('blogs', 'category', 'products', 'featured_products', 'banners'));
    }
    public function about_us()
    {
        $brands = Brand::all();
        
        $about_us_image = AboutUsImage::all();

        return view('about_us', compact('about_us_image','brands'));
    }
    public function shop(Request $request)
    {
        $products = Product::with('brand', 'category');

        if ($search = request('search')) {
            $products->where('name', 'LIKE', '%' . $search . '%');
        }

        if ($category = request('category')) {
            $products->where(function ($query) use ($category) {
                $query->where('category_id', $category)
                    ->orWhereHas('category', function ($query) use ($category) {
                        $query->where('name', 'LIKE', '%' . $category . '%');
                    });
            });
        }

        if ($brand = request('brand')) {
            $products->where('brand_id', $brand);
        }

        if ($priceRange = request('price')) {
            // Parse price range and filter
            [$minPrice, $maxPrice] = explode('-', $priceRange);
            $products->whereBetween('price', [(int)$minPrice, (int)$maxPrice]);
        }
        if ($request->has('sort_by') && in_array($request->sort_by, ['date', 'name'])) {
            $sortColumn = $request->sort_by == 'date' ? 'created_at' : 'name';
            $products = $products->orderBy($sortColumn, 'asc');
        } else {
            $products = $products->orderBy('created_at', 'desc'); // Default to latest news
        }

        $products = $products->paginate(12);
        $category = Category::all();
        $brands = Brand::all();

        $banners = Banner::all();

        return view('shop', compact('products', 'category', 'brands', 'banners'));
    }


    public function product_details($id)
    {
        $category = Category::all();
        $product_details = Product::findOrFail($id);
        $brands = Brand::all();
        $products = Product::all();
        $banners = Banner::all();
        return view('product_details', compact('product_details', 'category', 'brands', 'products', 'banners'));
    }

    public function blogs(Request $request)
    {
        $query = Blogs::with('category'); // Eager load the category relationship

        // Filter by category if provided
        if ($request->has('category') && $request->category) {
            $query->where('category_id', $request->category);
        }

        $allblogs = $query->paginate(12);

        // Retrieve all categories for the filter dropdown
        $categories = Category::all();

        $banners = Banner::all();

        return view('blogs', compact('allblogs', 'categories', 'banners'));
    }

    public function blogs_details($id)
    {
        $blogs = Blogs::findOrFail($id);

        $categories = Category::all();

        $allblogs = Blogs::orderBy('created_at', 'desc')->take(4)->get();

        $banners = Banner::all();

        return view('blogs_details', compact('blogs', 'allblogs', 'categories', 'banners'));
    }
    public function contact_us()
    {
        return view('contact_us');
    }
    public function cart()
    {
        // Retrieve cart data from the session
        $cart = session()->get('cart', []);

        // Fetch product details based on product IDs in the cart
        $products = Product::whereIn('id', array_keys($cart))->get();

        return view('cart', compact('cart', 'products'));
    }
    public function cart_login()
    {
        return view('cart_login');
    }
    public function place_order()
    {
        // Get the authenticated user
        $user = auth()->user();

        // Retrieve the billing information (assuming a 'billing' relationship exists on the User model)
        $billing = $user->billing->where('is_default', 1)->first(); // Adjust if necessary for your setup

        // Pass the billing information to the view
        return view('place_order', compact('billing'));
    }

    public function wishlist()
    {
        if (auth()->check()) {
            $user_id = auth()->user()->id;

            // Fetch wishlist items for the authenticated user
            $wishlist = Wishlist::where('user_id', $user_id)
                ->with('product')
                ->get();
        } else {
            // Handle the case where the user is not authenticated
            $wishlist = collect(); // Empty collection or handle as needed
        }

        $banners = Banner::all();

        return view('wishlist', compact('wishlist', 'banners'));
    }

    public function success($id)
    {
        $order = Order::with('billingInformation', 'orderDetails')->findOrFail($id);
        // Handle data and return a view or any other necessary logic
        return view('success', compact('order'));
    }
    public function login()
    {
        return view('login');
    }
    public function forgot_password()
    {
        return view('forgot_password');
    }
    public function verify()
    {
        return view('verify');
    }
    public function new_password()
    {
        return view('new_password');
    }
    public function register()
    {
        return view('register');
    }
    public function user_dashboard()
    {
        $user_id = auth()->user()->id;

        $orders = Order::with('billingInformation', 'orderDetails.product.images')->get();

        $subscriptions = Subscription::where('user_id', $user_id)
            ->with(['transactions.details.product'])
            ->get();

        return view('user_dashboard', compact('orders', 'subscriptions', 'user_id'));
    }

    public function purchase_history()
    {
        $orders = Order::with('billingInformation', 'orderDetails.product.images')->get();
        return view('purchase_history', compact('orders'));
    }

    public function user_profile()
    {
        return view('user_profile');
    }
    public function change_password()
    {
        return view('change_password');
    }
    public function payment_methods()
    {
        return view('payment_methods');
    }
    public function rewards()
    {
        $voucher = Voucher::all();

        return view('rewards', compact('voucher'));
    }
    public function subscription()
    {
        return view('subscription');
    }
}
