<?php

namespace App\Http\Controllers;

use App\Models\User;
use App\Mail\OtpMail;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Mail;

class PasswordController extends Controller
{
    public function showForgotPasswordForm()
    {
        return view('auth.forgot-password');
    }

    public function sendOtp(Request $request)
    {
        $request->validate(['email' => 'required|email|exists:users,email']);

        $user = User::where('email', $request->email)->first();
        $otp = rand(100000, 999999); // Generate a 6-digit OTP

        // Store OTP and email in session
        session(['otp' => $otp, 'email' => $request->email]);

        // Send OTP to user's email
        Mail::to($request->email)->send(new OtpMail($otp));

        return redirect('/verify')->with('success', 'OTP sent successfully!');
    }


    public function showOtpForm()
    {
        return view('otp');
    }

    public function verifyOtp(Request $request)
    {
        // Validate each OTP input field
        $request->validate([
            'otp1' => 'required|numeric|digits:6',
        ]);

        // Combine OTP inputs into a single string
        $otp = $request->otp1;

        // Compare the combined OTP with the session OTP
        if ($otp == session('otp')) {
            // Redirect to password reset form if OTP is correct
            return redirect('/new_password')->with('success', 'OTP verified successfully!');
        }

        // Return with an error if OTP is incorrect
        return back()->withErrors(['otp' => 'Invalid OTP']);
    }

    public function resend()
    {
        // Get the email from the session
        $userEmail = session('email');

        // Ensure the email exists in the session
        if (!$userEmail) {
            return response()->json(['success' => false, 'message' => 'No email found in the session.'], 400);
        }

        // Generate a new OTP
        $otp = rand(100000, 999999);

        // Save the new OTP to the session
        session(['otp' => $otp]);

        // Send the OTP to the stored email
        try {
            Mail::to($userEmail)->send(new OtpMail($otp));
            return response()->json(['success' => true, 'message' => 'OTP has been resent.']);
        } catch (\Exception $e) {
            return response()->json(['success' => false, 'message' => 'Failed to send OTP. Please try again.'], 500);
        }
    }

    public function updatePassword(Request $request)
    {
        $request->validate([
            'password' => 'required|min:6|confirmed',
        ]);

        $user = User::where('email', session('email'))->first();
        $user->password = bcrypt($request->password);
        $user->save();

        session()->forget(['otp', 'email']);

        return redirect('/login')->with('success', 'Password reset successfully!');
    }
}
