<?php

namespace App\Http\Controllers;

use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;

class UserController extends Controller
{
    public function updatePassword(Request $request)
    {
        // Validate the incoming data
        $validatedData = $request->validate([
            'current_password' => 'required|string|min:8',
            'new_password' => 'required|string|min:8|confirmed',
        ]);

        // Check if the current password is correct
        if (!Hash::check($validatedData['current_password'], Auth::user()->password)) {
            return back()->withErrors(['current_password' => 'The current password is incorrect.']);
        }

        // Update the password
        Auth::user()->update([
            'password' => Hash::make($validatedData['new_password']),
        ]);

        // Redirect back with a success message
        return back()->with('success', 'Password updated successfully!');
    }
    public function update(Request $request)
    {
        $request->validate([
            'name' => 'required|string|max:255',
            'email' => 'required|email',
            'contact_number' => 'nullable|numeric',
            'birthday' => 'nullable|date',
            'gender' => 'nullable|string',
            'image' => 'nullable|image|mimes:jpg,jpeg,png,gif|max:2048',
        ]);

        $user = Auth::user();

        // Update user data
        $user->name = $request->name;
        $user->email = $request->email;
        $user->contact_number = $request->contact_number;
        $user->birthday = $request->birthday;
        $user->gender = $request->gender;

        // Handle profile image upload
        if ($request->hasFile('image')) {
            // Generate a unique filename
            $fileName = time() . '.' . $request->file('image')->getClientOriginalExtension();

            // Move the file to the public/profile_images directory
            $request->file('image')->move(public_path('image'), $fileName);

            // Save the path to the image (it will be relative to the public directory)
            $user->image = 'image/' . $fileName;
        }

        $user->save();

        return redirect()->back()->with('success', 'Profile updated successfully.');
    }

    public function register(Request $request)
    {
        // Validate the incoming data
        $validated = $request->validate([
            'name' => 'required|string|max:255',
            'email' => 'required|string|email|max:255|unique:users',
            'password' => 'required|string|confirmed|min:8',
            'contact_number' => 'required|digits:11',
            'birthday' => 'required|date',
            'gender' => 'required|string',
        ]);

        // Create the user
        $user = User::create([
            'name' => $validated['name'],
            'email' => $validated['email'],
            'password' => Hash::make($validated['password']),
            'contact_number' => $validated['contact_number'],
            'birthday' => $validated['birthday'],
            'gender' => $validated['gender'],
            'role' => 'user',
        ]);

        // Log the user in
        Auth::login($user);

        // Flash session message for success
        session()->flash('success', 'Account successfully created!');

        // Redirect to the home or login page
        return redirect()->back(); // Or any route you prefer
    }
}
