<x-app-layout>
    <div class="container max-w-4xl p-6 mx-auto bg-white rounded-lg shadow-lg">
        <h1 class="mb-4 text-2xl font-bold">Create Products</h1>

        <form action="{{ route('products.store') }}" method="POST" enctype="multipart/form-data" class="grid grid-cols-1 gap-8 md:grid-cols-2">
            @csrf

            <div class="mb-4">
                <label for="category_name" class="block text-gray-700">Category:</label>
                <select id="category_name" name="category_name" class="w-full p-2 border border-gray-300 rounded" required>
                    <option value="">Select Category</option>
                    @foreach($categories as $category)
                    <option value="{{ $category->name }}"
                        {{ old('category_name') == $category->name ? 'selected' : '' }}>
                        {{ $category->name }}
                    </option>
                    @endforeach
                    <option value="add_new">Add New Category</option>
                </select>

                <input type="text" id="new_category" name="new_category" class="hidden w-full p-2 mt-2 border border-gray-300 rounded"
                    value="{{ old('new_category') }}" placeholder="Enter new category">

                @error('category_name')
                <span class="text-red-500">{{ $message }}</span>
                @enderror
            </div>

            <div class="mb-4">
                <label for="brand" class="block text-gray-700">Brand:</label>
                <select id="brand" name="brand" class="w-full p-2 border border-gray-300 rounded" required>
                    <option value="">Select Brand</option>
                    @foreach($brands as $brand)
                    <option value="{{ $brand->brand_name }}"
                        {{ old('brand') == $brand->brand_name ? 'selected' : '' }}>
                        {{ $brand->brand_name }}
                    </option>
                    @endforeach
                    <option value="add_new">Add New Brand</option>
                </select>

                <input type="text" id="new_brand" name="new_brand" class="hidden w-full p-2 mt-2 border border-gray-300 rounded"
                    value="{{ old('new_brand') }}" placeholder="Enter new brand">

                @error('brand')
                <span class="text-red-500">{{ $message }}</span>
                @enderror
            </div>

            <script>
                // Show the new category input field when "Add New Category" is selected
                document.getElementById('category_name').addEventListener('change', function() {
                    var newCategoryInput = document.getElementById('new_category');
                    if (this.value === 'add_new') {
                        newCategoryInput.classList.remove('hidden');
                        newCategoryInput.setAttribute('required', 'required');
                    } else {
                        newCategoryInput.classList.add('hidden');
                        newCategoryInput.removeAttribute('required');
                    }
                });

                // Show the new brand input field when "Add New Brand" is selected
                document.getElementById('brand').addEventListener('change', function() {
                    var newBrandInput = document.getElementById('new_brand');
                    if (this.value === 'add_new') {
                        newBrandInput.classList.remove('hidden');
                        newBrandInput.setAttribute('required', 'required');
                    } else {
                        newBrandInput.classList.add('hidden');
                        newBrandInput.removeAttribute('required');
                    }
                });
            </script>


            <div class=" md:col-span-2">
                <label for="name" class="block text-gray-700">Name:</label>
                <input type="text" value="{{old('name')}}" required id="name" name="name"
                    class="w-full p-2 border border-gray-300 rounded">
                @error('name')
                <span class="text-red-500">{{ $message }}</span>
                @enderror
            </div>

            <div class="">
                <label for="price" class="block text-gray-700">Price:</label>
                <input type="number" value="{{old('price')}}" required id="price" name="price"
                    class="w-full p-2 border border-gray-300 rounded">
                @error('price')
                <span class="text-red-500">{{ $message }}</span>
                @enderror
            </div>

            <div class="">
                <label for="stock" class="block text-gray-700">Stock:</label>
                <input type="number" value="{{old('stock')}}" required id="stock" name="stock"
                    class="w-full p-2 border border-gray-300 rounded">
                @error('stock')
                <span class="text-red-500">{{ $message }}</span>
                @enderror
            </div>


            <div class=" md:col-span-2">
                <label for="description" class="block text-gray-700">Description:</label>
                <textarea id="description" name="description" class="w-full p-2 border border-gray-300 rounded">{{old('description')}}</textarea>
                @error('description')
                <span class="text-red-500">{{ $message }}</span>
                @enderror
            </div>

            <div class=" md:col-span-2">
                <label for="shipping_and_returns" class="block text-gray-700">Shipping and Returns:</label>
                <textarea id="shipping_and_returns" name="shipping_and_returns" class="w-full p-2 border border-gray-300 rounded">{{old('shipping_and_returns')}}</textarea>
                @error('shipping_and_returns')
                <span class="text-red-500">{{ $message }}</span>
                @enderror
            </div>

            <div class="mb-4 md:col-span-2">
                <label for="image[]" class="block text-gray-700">Image :</label>
                <input type="file" multiple id="image[]" name="image[]"
                    accept="image/webp,image/jpg,image/jpeg,image/png,image/gif"
                    class="w-full p-2 border border-gray-300 rounded">
                @error('image')
                <span class="text-red-500">{{ $message }}</span>
                @enderror
            </div>

            <button type="submit" class="px-12 py-2 text-white bg-black rounded-full">Submit</button>
        </form>
    </div>

    <script src="https://cdn.ckeditor.com/4.16.0/standard/ckeditor.js"></script>

    <script>
        CKEDITOR.replace('description');
    </script>
</x-app-layout>