<x-app-layout>
    <div class="container p-4 mx-auto">
        <h1 class="mb-4 text-2xl font-bold">Products</h1>
        <a href="{{ route('products.create') }}" class="px-4 py-2 text-white bg-black rounded-full">
            <i class='bx bx-add-to-queue'></i> Add New Products
        </a>
    </div>

    <section class="container px-4 mx-auto">
        <div class="flex flex-col">
            <div class="-mx-4 -my-2 overflow-x-auto sm:-mx-6 lg:-mx-8">
                <div class="inline-block min-w-full py-2 align-middle md:px-6 lg:px-8">
                    <div class="overflow-hidden border border-gray-200 md:rounded-lg">
                        <table id="productsTable" class="min-w-full divide-y divide-gray-200">
                            <thead class="bg-gray-50">
                                <tr>
                                    <th scope="col" class="py-3.5 px-4 text-sm font-normal text-left rtl:text-right text-gray-500">
                                        <div class="flex items-center gap-x-3">
                                            <span>Id</span>
                                        </div>
                                    </th>
                                    <th scope="col" class="px-4 py-3.5 text-sm font-normal text-left rtl:text-right text-gray-500">
                                        Category
                                    </th>
                                    <th scope="col" class="px-4 py-3.5 text-sm font-normal text-left rtl:text-right text-gray-500">
                                        Brand
                                    </th>
                                    <th scope="col" class="px-4 py-3.5 text-sm font-normal text-left rtl:text-right text-gray-500">
                                        Product Name
                                    </th>
                                    <th scope="col" class="px-4 py-3.5 text-sm font-normal text-left rtl:text-right text-gray-500">
                                        Price
                                    </th>
                                    <th scope="col" class="px-4 py-3.5 text-sm font-normal text-left rtl:text-right text-gray-500">
                                        Stock
                                    </th>
                                    <th scope="col" class="px-4 py-3.5 text-sm font-normal text-left rtl:text-right text-gray-500">
                                        Availability
                                    </th>
                                    <th scope="col" class="px-4 py-3.5 text-sm font-normal text-left rtl:text-right text-gray-500">
                                        Featured
                                    </th>
                                    <th scope="col" class="relative py-3.5 px-4">
                                        <span class="sr-only">Actions</span>
                                    </th>
                                </tr>
                            </thead>
                            <tbody class="bg-white divide-y divide-gray-200">
                                <!-- DataTables will fill this -->
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>
        </div>
    </section>

    <script>
        $(document).ready(function() {
            var table = $('#productsTable').DataTable({
                processing: true,
                serverSide: true,
                ajax: "{{ route('products.index') }}",
                columns: [{
                        data: 'id',
                        name: 'id'
                    },
                    {
                        data: 'category',
                        name: 'category'
                    },
                    {
                        data: 'brand',
                        name: 'brand'
                    },
                    {
                        data: 'name',
                        name: 'name'
                    },
                    {
                        data: 'price',
                        name: 'price'
                    },
                    {
                        data: 'stock',
                        name: 'stock'
                    },
                    {
                        data: 'availability',
                        name: 'availability',
                        render: function(data, type, row) {
                            var availabilityText = data === 'In Stock' ? 'In Stock' : 'Out of Stock';
                            return `
                            <div class="availability-container">
                                <input type="checkbox" class="availability-checkbox" data-id="${row.id}" ${data === 'In Stock' ? 'checked' : ''} />
                                <span class="availability-text">${availabilityText}</span>
                            </div>
                        `;
                        }
                    },
                    {
                        data: 'featured',
                        name: 'featured',
                        render: function(data, type, row) {
                            var featuredText = data === 'Featured' ? 'Featured' : 'Not Featured'; // Fixed the issue here
                            return `
                            <div class="featured-container">
                                <input type="checkbox" class="featured-checkbox" data-id="${row.id}" ${data === 'Featured' ? 'checked' : ''} />
                                <span class="featured-text">${featuredText}</span> 
                            </div>
                        `;
                        }
                    },
                    {
                        data: 'action',
                        name: 'action',
                        orderable: false,
                        searchable: false
                    }
                ]
            });

            // Handling checkbox change event
            $(document).on('change', '.availability-checkbox', function() {
                var productId = $(this).data('id');
                var isChecked = $(this).prop('checked');

                // Sending an AJAX request to update availability
                $.ajax({
                    route: `{{url('/public/admin/update-availability/${productId}')}}`,
                    method: 'POST',
                    data: {
                        _token: '{{ csrf_token() }}',
                        availability: isChecked ? "In Stock" : "Out of Stock" // Determine availability status
                    },
                    success: function(response) {
                        table.ajax.reload();
                    }
                });
            });

            $(document).on('change', '.featured-checkbox', function() {
                var productId = $(this).data('id');
                var isChecked = $(this).prop('checked');

                // Sending an AJAX request to update featured status
                $.ajax({
                    url: `{{url('/public/admin/products/update-featured/${productId}')}}`,
                    method: 'POST',
                    data: {
                        _token: '{{ csrf_token() }}',
                        featured: isChecked ? "Featured" : "Not Featured" // Determine featured status
                    },
                    success: function(response) {
                        table.ajax.reload();
                    }
                });
            });
        });
    </script>
</x-app-layout>