<x-app-layout>
    <div class="container max-w-4xl p-6 mx-auto bg-white rounded-lg shadow-lg">
        <h1 class="mb-4 text-2xl font-bold">Edit Transaction</h1>
        <form action="{{ route('subscription.transaction.update', $transaction->id) }}" method="POST" enctype="multipart/form-data" class="space-y-2">
            @csrf
            @method('PUT')
            <input type="text" hidden readonly value="{{ $transaction->subscription_id }}" required id="subscription_id[]" name="subscription_id[]" class="w-full p-2 border border-gray-300 rounded">
            <div id="transaction-fields">
                @foreach($transaction->details as $item)
                <div class="grid w-full grid-cols-3 gap-2 transaction-row">
                    <div>
                        <label for="product_id" class="block text-gray-700">Product:</label>
                        <select required id="product_id" name="product_id[]" class="w-full p-2 border border-gray-300 rounded product-select">
                            <option value="">Select a product</option>
                            @foreach ($products as $product)
                            <option value="{{ $product->id }}" data-price="{{ $product->price }}" {{ $item->product_id == $product->id ? 'selected' : '' }}>
                                {{ $product->name }}
                            </option>
                            @endforeach
                        </select>
                        @error('product_id')
                        <span class="text-red-500">{{ $message }}</span>
                        @enderror
                    </div>

                    <div>
                        <label for="price" class="block text-gray-700">Price:</label>
                        <input type="text" required value="{{ $item->price }}" id="price" name="price[]" class="w-full p-2 border border-gray-300 rounded" readonly>
                        @error('price')
                        <span class="text-red-500">{{ $message }}</span>
                        @enderror
                    </div>

                    <div>
                        <label for="quantity" class="block text-gray-700">Quantity:</label>
                        <input type="number" value="{{ $item->quantity }}" required id="quantity" name="quantity[]" class="w-full p-2 border border-gray-300 rounded">
                        @error('quantity')
                        <span class="text-red-500">{{ $message }}</span>
                        @enderror
                    </div>
                </div>
                @endforeach
            </div>
            <div class="col-span-3">
                <label for="note" class="block text-gray-700">Note:</label>
                <textarea id="note" name="note" class="w-full p-2 border border-gray-300 rounded">{{ $transaction->note }}</textarea>
                @error('note')
                <span class="text-red-500">{{ $message }}</span>
                @enderror
            </div>
            <div class="flex justify-between col-span-3">
                <button type="button" id="add-row" class="px-12 py-2 text-white bg-black rounded-full">Add</button>
            </div>
            <div class="flex justify-center py-4">
                <button type="submit" class="px-12 py-2 text-white bg-black rounded-full">Update</button>
            </div>
        </form>
    </div>
    <script>
        // When the "Add" button is clicked, clone the last row of inputs and append it
        document.getElementById('add-row').addEventListener('click', function() {
            var lastRow = document.querySelector('.transaction-row');
            var newRow = lastRow.cloneNode(true);

            // Reset the input fields to be empty (optional)
            var inputs = newRow.querySelectorAll('input, select, textarea');
            inputs.forEach(function(input) {
                input.value = '';
            });

            // Append the new row to the form
            document.getElementById('transaction-fields').appendChild(newRow);

            // Reinitialize event listeners for the newly added select elements
            initializeProductSelect(newRow);
        });

        // Update price field based on the selected product
        document.addEventListener('DOMContentLoaded', function() {
            // Initialize event listeners for all product selects
            document.querySelectorAll('.product-select').forEach(function(selectElement) {
                initializeProductSelect(selectElement.closest('.transaction-row'));
            });
        });

        // Function to initialize price update for product select elements
        function initializeProductSelect(row) {
            var productSelect = row.querySelector('.product-select');
            productSelect.addEventListener('change', function() {
                var selectedOption = this.options[this.selectedIndex];
                var price = selectedOption.getAttribute('data-price');
                var priceInput = row.querySelector('input[name="price[]"]');
                priceInput.value = price; // Set the price value
            });

            // Trigger change event to set the initial price value if any product is pre-selected
            if (productSelect.value) {
                var selectedOption = productSelect.options[productSelect.selectedIndex];
                var price = selectedOption.getAttribute('data-price');
                var priceInput = row.querySelector('input[name="price[]"]');
                priceInput.value = price;
            }
        }
    </script>
</x-app-layout>