<!-- contact_us.blade.php -->
@extends('layouts.main-app')

@section('title', 'Shop')

@section('content')

@include('layouts.navbar')


@include('layouts.brands')

<div class="bg-gray-100">
    <div class="container max-w-screen-xl py-8 mx-auto space-y-8">
        <div data-aos="fade-up"
            data-aos-duration="1500">
            <h1 class="text-[#cf000f] font-bold text-2xl">CATEGORIES</h1>
            @include('layouts.category')
        </div>

        <div class="grid gap-8 px-4 overflow-hidden lg:grid-cols-3">
            <div data-aos="fade-right"
                data-aos-duration="1500">
                @include('layouts.shop_filter')
            </div>
            <div data-aos="fade-left"
                data-aos-duration="1500" class="lg:col-span-2">
                <div class="flex flex-wrap items-center justify-between gap-4">
                    <div>
                        <h1>Showing {{ $products->firstItem() }}-{{ $products->lastItem() }} of {{ $products->total() }} Products</h1>
                    </div>
                    <div class="flex items-center space-x-2">
                        <h1 class="text-nowrap">Sort By</h1>
                        <form action="{{ url('shop') }}" method="GET">
                            <select name="sort_by" class="border border-[#cf000f] w-40 h-full p-2 bg-white rounded" onchange="this.form.submit()">
                                <option value=""></option>
                                <option value="date" {{ request('sort_by') == 'date' ? 'selected' : '' }}>Date</option>
                                <option value="title" {{ request('sort_by') == 'title' ? 'selected' : '' }}>Title</option>
                            </select>
                        </form>
                    </div>
                </div>

                <div class="grid grid-cols-1 gap-4 pt-4 md:grid-cols-2 lg:grid-cols-3 xl:grid-cols-4">
                    @foreach ($products as $product)
                    @include('layouts.product')
                    @endforeach

                </div>
                <div class="flex items-center justify-end my-4 space-x-8">
                    <div>
                        @if ($products->onFirstPage())
                        <button id="prev-button" class="w-8 h-8 text-white rounded-full bg-[#cf000f]" disabled><i class='bx bx-chevron-left'></i></button>
                        @else
                        <a href="{{ $products->previousPageUrl() }}">
                            <button id="prev-button" class="w-8 h-8 text-white rounded-full bg-[#cf000f]"><i class='bx bx-chevron-left'></i></button>
                        </a>
                        @endif
                    </div>
                    <div class="flex flex-wrap gap-2">
                        @foreach ($products->getUrlRange(1, $products->lastPage()) as $page => $url)
                        <a href="{{ $url }}">
                            <button class="w-8 h-8 text-sm bg-white rounded-full {{ $page == $products->currentPage() ? 'bg-red-600 text-white' : '' }}">
                                {{ $page }}
                            </button>
                        </a>
                        @endforeach
                    </div>
                    <div>
                        @if ($products->hasMorePages())
                        <a href="{{ $products->nextPageUrl() }}">
                            <button id="next-button" class="w-8 h-8 text-white rounded-full bg-[#cf000f]"><i class='bx bx-chevron-right'></i></button>
                        </a>
                        @else
                        <button id="next-button" class="w-8 h-8 text-white rounded-full bg-[#cf000f]" disabled><i class='bx bx-chevron-right'></i></button>
                        @endif
                    </div>
                </div>

            </div>
        </div>
    </div>
</div>

@include('layouts.footer')
@endsection